log using nlp1, replace text
*
* This STATA program estimates the default model in STATA, and tests for integration.
* A one-factor model is used initially (only firm intercepts).
*
* Start up
*
drop _all
program drop _all
macro drop _all
set more 1
set mem 40m
set matsize 300
set trace off
*set trace on
*
* Read in the data and clean it up some
*
use \res\stockreg\data\datal1
*
* Retain only the first sample, only for S&P 500
*
drop if sample~=1
drop if asset~=1
drop sample asset pdol index
*
* Create the regressor and regressand
*
sort firmn period
g lhs=p[_n+1]/p[_n-1] if (firmn[_n+1]==firmn[_n-1])&(period[_n+1]==(2+period[_n-1]))
g rhs=p/p[_n-1] if (firmn==firmn[_n-1])&(period==(1+period[_n-1]))
*
* Clean up a little
*
drop p
drop if lhs==.
drop if rhs==.
sort firmn period
*
* Declare coefficients (D's for time; B's for firms)
*
do Params199945
*
* Define the dimensions of the data set
*
local TT=42 /* number of periods, +1 for initial lag lost */
local II=100  /* number of firms */
*
* Generate the time and firm specific dummies
*
global nn=2
while $nn<=`TT' {
g byte t$nn=0
replace t$nn=1 if period==$nn
global nn=$nn+1
}

global nn=1
while $nn<=`II' {
g byte f$nn=0
replace f$nn=1 if firmn==$nn
global nn=$nn+1
}
*
* The Non-linear function
*
program define nlfr
  if "`1'"== "?" {		
    global S_1 "$param0 $param1" /* declare parameters */
      * Start all Ds at 1 for estimation
      foreach param in $param0 {
      global `param'=1
      }
      * Start all Bs at 0 for estimation
      foreach param in $param1 {
      global `param'=0
      }
      exit
    }
*
* We now generate the components of the estimating equation.
* tvI captures a summation of terms of the form Bi*fi where i goes from 1 to 100
* tvT captures a summation of terms of the form Di*ti where i goes from 2 to 42
*
    tempvar tvI tvT
    g `tvI'= $B1*f1
    forvalues i=2/100 {
      replace `tvI'= `tvI' + (${B`i'}*f`i')
      }
    g `tvT'= $D2*t2
    forvalues i=3/42 {
      replace `tvT'= `tvT' + (${D`i'}*t`i')
      }
    replace `1'=(`tvT')*(rhs+(`tvI'))
    end
*
* Perform the estimation
*
nl fr lhs
*
* Clean up and close down
*
drop _all
program drop _all
macro drop _all
set trace off
set mem 1m
set more 0
log close
exit,clear
